Rule

Enum Rule 

pub enum Rule {
    NoteHistoryOnly,
    RequireDepositForRebooking,
    ManagerReviewBeforeRebooking,
}
Rebooking rule that tells staff whether history only, deposit review, or manager review applies.

Variants



NoteHistoryOnly

Staff can see the note history only grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.



RequireDepositForRebooking

Staff can see the require deposit for rebooking grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.



ManagerReviewBeforeRebooking

Staff can see the manager review before rebooking grooming state during grooming scheduling, estimate, history, rebooking, reminder, or review work.